<?php

// Enqueue 3D theme scripts
add_action('wp_enqueue_scripts', function() {
  if(is_front_page()) {
    wp_enqueue_script('three-js', get_template_directory_uri().'/js/webgl.js', array(), '0.132.2', true);
    wp_enqueue_script('main-js', get_template_directory_uri().'/js/main.js', array('three-js'), filemtime(get_template_directory().'/js/main.js'), true);
  }
});
// Handle contact form submissions
add_action('wp_ajax_submit_contact', 'handle_contact_form');
add_action('wp_ajax_nopriv_submit_contact', 'handle_contact_form');

function handle_contact_form() {
    check_ajax_referer('contact_form');

    $data = [
        'name' => sanitize_text_field($_POST['name']),
        'email' => sanitize_email($_POST['email']),
        'message' => sanitize_textarea_field($_POST['message'])
    ];

    $to = get_option('admin_email');
    $subject = 'New contact from ' . $data['name'];
    $headers = ['Content-Type: text/html; charset=UTF-8'];

    wp_mail($to, $subject, $data['message'], $headers);

    wp_send_json_success(['message' => 'Thank you! Your message has been sent.']);
}

// MemberPress integration
if (class_exists('MeprAppCtrl')) {
    add_filter('mepr-pre-run-rule-content', function($allowed, $post) {
        if (is_page('premium-content')) {
            return MeprUser::is_logged_in_and_current_user_valid();
        }
        return $allowed;
    }, 10, 2);

    add_shortcode('member_content', function($atts, $content = null) {
        if (MeprUser::is_logged_in_and_current_user_valid()) {
            return do_shortcode($content);
        }
        return '<div class="member-cta three-d-item">Please subscribe to access premium content</div>';
    });
}

function theme_scripts() {
    wp_register_script(
        'threejs',
        'https://cdn.skypack.dev/three@0.136.0',
        array(),
        '0.136.0',
        true
    );

    wp_enqueue_script(
        'webgl-background',
        get_template_directory_uri() . '/js/webgl.js',
        array('threejs'),
        '1.0',
        true
    );
    
    wp_enqueue_script(
        '3d-theme-main', 
        get_template_directory_uri() . '/js/main.js', 
        array('webgl-background'), 
        '1.0', 
        true
    );
}
add_action('wp_enqueue_scripts', 'theme_scripts');

function theme_setup() {
    add_theme_support('title-tag');
    add_theme_support('post-thumbnails');
}
add_action('after_setup_theme', 'theme_setup');

// MemberPress integration
add_action('mepr_extra_profile_fields', function($user) {
    echo '<div class="three-d-item">';
    echo '<label>3D Theme Custom Field</label>';
    echo '<input type="text" name="custom_field">';
    echo '</div>';
});

add_filter('mepr_signup_redirect_url', function($url) {
    return home_url('/members-area/');
});

add_filter('mepr_account_nav_items', function($items) {
    $items[] = array('slug' => '3d-settings', 'label' => '3D Settings');
    return $items;
});


// Add module type for WebGL script
add_filter('script_loader_tag', function($tag, $handle) {
    if ($handle === 'webgl-background') {
        return str_replace(' src', ' type="module" src', $tag);
    }
    return $tag;
}, 10, 2);