// Scroll-triggered animations
document.addEventListener('DOMContentLoaded', () => {
  const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        entry.target.classList.add('in-view');
      }
    });
  }, {
    threshold: 0.1
  });

  // Animate 3D elements on scroll
  document.querySelectorAll('.three-d-item').forEach((element) => {
    observer.observe(element);
  });
});

// 3D container interaction
const containers = document.querySelectorAll('.three-d-container');

containers.forEach(container => {
  let rotateX = 0;
  let rotateY = 0;
  
  container.addEventListener('mousemove', (e) => {
    const rect = container.getBoundingClientRect();
    const centerX = rect.left + rect.width/2;
    const centerY = rect.top + rect.height/2;

    // Contact form handling for HTML version
    document.querySelectorAll('.contact-form').forEach(form => {
      form.addEventListener('submit', (e) => {
        e.preventDefault();
        const responseDiv = form.querySelector('.form-response');
        responseDiv.textContent = 'Thank you! Demo message sent.';
        responseDiv.style.display = 'block';
        form.reset();
        setTimeout(() => responseDiv.style.display = 'none', 3000);
      });
    });
    
    rotateX = (e.clientY - centerY) * 0.02;
    rotateY = (e.clientX - centerX) * -0.02;
    
    container.style.transform = `
      perspective(1000px)
      rotateX(${rotateX}deg)
      rotateY(${rotateY}deg)
    `;
  });

  container.addEventListener('mouseleave', () => {
    container.style.transition = 'transform 0.5s ease';
    container.style.transform = 'perspective(1000px) rotateX(0) rotateY(0)';
    setTimeout(() => container.style.transition = '', 500);
  });
});