// Three.js scene initialization
import * as THREE from 'https://unpkg.com/three@0.136.0/build/three.module.js';

class WebGLBackground {
  constructor() {
    this.canvas = document.querySelector('.webgl-canvas');
    this.scene = new THREE.Scene();
    this.camera = new THREE.PerspectiveCamera(75, window.innerWidth/window.innerHeight, 0.1, 1000);
    this.renderer = new THREE.WebGLRenderer({ canvas: this.canvas, alpha: true });
    
    this.setupScene();
    this.addEventListeners();
    this.animate();
  }

  setupScene() {
    const geometry = new THREE.IcosahedronGeometry(3);
    const material = new THREE.MeshPhongMaterial({
      color: 0xffffff,
      shininess: 100,
      wireframe: true
    });
    
    this.mesh = new THREE.Mesh(geometry, material);
    this.scene.add(this.mesh);
    
    const light = new THREE.DirectionalLight(0xffffff, 1);
    light.position.set(5, 5, 5);
    this.scene.add(light);
    
    this.camera.position.z = 15;
  }

  addEventListeners() {
    window.addEventListener('resize', () => this.onWindowResize());
  }

  onWindowResize() {
    this.camera.aspect = window.innerWidth / window.innerHeight;
    this.camera.updateProjectionMatrix();
    this.renderer.setSize(window.innerWidth, window.innerHeight);
  }

  animate() {
    requestAnimationFrame(() => this.animate());
    this.mesh.rotation.x += 0.005;
    this.mesh.rotation.y += 0.005;
    this.renderer.render(this.scene, this.camera);
  }
}

new WebGLBackground();